from ezdxf import colors

def add_section_header(msp, text='VIEW', font_height=6, x_offset=0, y_offset=0, scale_text="1/2\" = 1' - 0\""):
    line_length = len(text) * 7.5
    msp.add_text(text, dxfattribs={'insert': (x_offset, y_offset), 'layer': 'DIM', 'color': colors.BLUE, 'height': font_height})
    msp.add_line((x_offset - 5, y_offset - 5), (x_offset + line_length, y_offset - 5), dxfattribs={'layer': 'DIM', 'color': colors.RED})
    msp.add_text(scale_text, dxfattribs={'insert': (x_offset + line_length * 0.6, y_offset - 10), 'layer': 'DIM', 'color': colors.YELLOW, 'height': 2.5})


def draw_horizontal_dimension_line_right(msp, x_offset=0, y_offset=0, dist=35, height=30, val="", layer='MUA-DUCT'):
    dim = msp.add_linear_dim(
        base=(x_offset + dist, y_offset),  
        p1=(x_offset, y_offset),  
        p2=(x_offset, y_offset - height),  
        dimstyle=layer,
        override={
            "dimtsz": 0,  
            "dimasz": 1,  
            "dimdle": 2,
            "dimexe": 2,
            "dimltype": "DASHED2",
            "dimblk": "ARCHTICK",
            "dimtxt": 2,
            "dimclrd": 2,  # Dimension line color (2 corresponds to yellow in AutoCAD color index)
            "dimclre": 2,  # Extension line color
            "dimclrt": 2,  # Text color
        },
        text=val,
        angle=90,  
    )
    
    dim.render()

def draw_horizontal_dimension_line_left(msp, x_offset=0, y_offset=0, height=30, dist=45, val="", layer='HOOD-ACCESSORIES'):
    dim = msp.add_linear_dim(
        base=(x_offset - dist, y_offset),  
        p1=(x_offset, y_offset),  
        p2=(x_offset, y_offset - height),  
        dimstyle=layer,
        override={
            "dimtsz": 0,  
            "dimasz": 1,  
            "dimdle": 2,
            "dimexe": 2,
            "dimltype": "DASHED2",
            "dimblk": "ARCHTICK",
            "dimtxt": 2,
            "dimclrd": 2,  # Dimension line color (2 corresponds to yellow in AutoCAD color index)
            "dimclre": 2,  # Extension line color
            "dimclrt": 2,  # Text color
        },
        text=val,
        angle=90,  
    )
    
    dim.render()


def draw_vertical_dimension_line(msp, x_offset=0, y_offset=0, height=30, width=111, val_center="", val_top="", layer='HOOD-ACCESSORIES', from_height = False):
    
    custom_y_offset = (y_offset - height) if(from_height == False) else y_offset
    
    dim = msp.add_linear_dim(
        base=(x_offset, y_offset - height - 10),
        p1=(x_offset, custom_y_offset),
        # p1=(x_offset, y_offset),
        p2=(x_offset + width, custom_y_offset),
        # p2=(x_offset + width, y_offset),
        dimstyle=layer,
        override={
            "dimtsz": 0,
            "dimasz": 1,
            "dimdle": 2,
            "dimexe": 2,
            "dimblk": "ARCHTICK",
            "dimtxt": 2,
            "dimclrd": 2,  # Dimension line color (2 corresponds to yellow in AutoCAD color index)
            "dimclre": 2,  # Extension line color
            "dimclrt": 2,  # Text color
        },
        angle=0,
        text=f"{val_top}\"",
    )
    
    dim.render()
    
    
    msp.add_text(
        text=val_center,
        dxfattribs={
            'insert': (x_offset + width / 2 - 3, y_offset - height - 10 - 5),  
            'layer': layer,
            'color': 2, 
            'height': 2
        }
    )
