from django.shortcuts import render
from django.http import HttpResponse, FileResponse
from .forms import CreateDrawingForm
from .create_drawing import draw as create_drawing_file
import os
import logging


def index(request):
    context = {
        'create_drawing_form': CreateDrawingForm(),
    }
    return render(request, 'createdrawing/create_drawing.html', context)


logger = logging.getLogger('myapp')


def draw(request):
    if request.method == 'POST':
        form = CreateDrawingForm(request.POST)

        if form.is_valid():
            form_data = request.POST

            def get_values(key):
                return request.POST.getlist(key)

            def extract_value(values, index):
                if index < len(values):
                    value = values[index]
                    try:
                        return int(value) if value.isdigit() else value
                    except ValueError:
                        return value
                return None

            # number of hoods
            hood_no_values = get_values('hood_no')
            number_of_hoods = len(hood_no_values)

            json_data = {
                'InputParams': {
                    'CABINETLEFTCHEEK': extract_value(get_values('cab_left_cheek'), 0),
                    'CABINETRIGHTCHEEK': extract_value(get_values('cab_right_cheek'), 0),
                    'PLENUMDEPTH': extract_value(get_values('plenum_depth'), 0),
                    'PLENUMLENGTH': extract_value(get_values('plenum_length'), 0),
                    'TAPERFROMTOP': extract_value(get_values('tapper_from_top'), 0),
                    'TAPERFROMBACK': extract_value(get_values('tapper_from_back'), 0),
                    'HEATSENSOR': extract_value(get_values('heat_sensor'), 0),
                    'TOPOFHOOD': extract_value(get_values('top_of_hood'), 0),
                    'HOODFRONT': extract_value(get_values('hood_front'), 0),
                    'HOODBACK': extract_value(get_values('hood_back'), 0),
                    'VISIBILITY1': extract_value(get_values('visibility'), 0),
                    'CABINETLOCATION': extract_value(get_values('cab_location'), 0),
                    'HOOD_INFORMATION': [],
                    'CABINET_INFORMATION': [],
                    'HOOD_SCHEDULE_INFO': [],
                    'PLENUM_SCHEDULE_INFO': [],
                    'FAN_SCHEDULE_INFO': [],
                }
            }

            # HOOD INFORMATION
            for i in range(number_of_hoods):
                hood_info = {
                    'HOODLENGTH': extract_value(get_values('hood_length'), i),
                    'HOODWIDTH': extract_value(get_values('hood_width'), i),
                    'HOODHEIGHT': extract_value(get_values('hood_height'), i),
                    'HANGHEIGHT': extract_value(get_values('hang_height'), i),
                    'HOOD_PLAN': extract_value(get_values('hang_plan'), i),
                    'HOOD_ELEV': extract_value(get_values('hang_elev'), i),
                    'HOOD_SECT': extract_value(get_values('hang_sect'), i),
                    'DRAIN': extract_value(get_values('drain_location'), i),
                    'RIGHTCHEEK': extract_value(get_values('hood_rc_config'), i),
                    'LEFTCHEEK': extract_value(get_values('hood_lc_config'), i),
                    'EXH_COLLAR_LOCATION_INFORMATION': [{
                        'EXHCOLLARLENGTH': extract_value(get_values('exh_collar_length'), i),
                        'EXHCOLLARWIDTH': extract_value(get_values('exh_collar_width'), i),
                        'EXHCOLLARLOCATION': extract_value(get_values('exh_collar_loc'), i)
                    }],
                    'MUA_COLLAR_LOCATION_INFORMATION': [{
                        'MUACOLLARLENGTH': extract_value(get_values('mua_collar_length'), i),
                        'MUACOLLARWIDTH': extract_value(get_values('mua_collar_width'), i),
                        'MUA_COLLAR_LOCATION': extract_value(get_values('mua_collar_loc'), i)
                    }]
                }
                json_data['InputParams']['HOOD_INFORMATION'].append(hood_info)

            # CABINET INFORMATION
            cabinet_values = get_values('cab_visibility')
            for i in range(len(cabinet_values)):
                cabinet_info = {
                    'CABINETVISIBILITY': extract_value(cabinet_values, i),
                    'CABINETSIZE': extract_value(get_values('cab_size'), i),
                    'CABINETHEIGHT': extract_value(get_values('cab_height'), i),
                    'CABINETWIDTH': extract_value(get_values('cab_width'), i),
                    'REMOTECABINETTYPE': extract_value(get_values('remote_cab_type'), i),
                    'CONTROLTYPE': extract_value(get_values('control_type'), i),
                    'TANKQTY': extract_value(get_values('tank_qty'), i)
                }
                json_data['InputParams']['CABINET_INFORMATION'].append(cabinet_info)

            # HOOD SCHEDULE INFO
            for i in range(number_of_hoods):
                hood_schedule_info = {
                    'HOOD_NO': extract_value(get_values('hood_no'), i),
                    'MFG': extract_value(get_values('hood_mfg'), i),
                    'MODEL': extract_value(get_values('hood_model'), i),
                    'HOOD_TYPE': extract_value(get_values('hood_type'), i),
                    'MATERIAL': extract_value(get_values('hood_meterial'), i),
                    'HOOD_WGT': extract_value(get_values('hood_weight'), i),
                    'EXH_COLLAR_QTY': extract_value(get_values('exh_collar_qty'), i),
                    'EXH_COLLAR_SP': extract_value(get_values('exh_collar_sp'), i),
                    'EXH_COLLAR_AREA': extract_value(get_values('exh_collar_area'), i),
                    'EXH_COLLAR_CFM': extract_value(get_values('exh_collar_cfm'), i),
                    'GREASE_COLLAR_VELOCITY': extract_value(get_values('grease_duct_vel'), i),
                    'FILTER_TYPE': extract_value(get_values('filter_type'), i),
                    'FILTER_QTY1': extract_value(get_values('filter_qty1'), i),
                    'FILTER_SIZE1': extract_value(get_values('filter_size1'), i),
                    'FILTER_QTY2': extract_value(get_values('filter_qty2'), i),
                    'FILTER_SIZE2': extract_value(get_values('filter_size2'), i),
                    'FILTER_AREA': extract_value(get_values('filter_area'), i),
                    'FILTER_VELOCITY': extract_value(get_values('filter_vel'), i),
                    'LIGHT_QTY': extract_value(get_values('lights_qty'), i),
                    'LIGHT_TYPE': extract_value(get_values('lights_type'), i),
                    'SWITCH_HOOD': extract_value(get_values('switch_hood'), i),
                    'SWITCH_LIGHT': extract_value(get_values('switch_light'), i)
                }
                json_data['InputParams']['HOOD_SCHEDULE_INFO'].append(hood_schedule_info)

            # PLENUM SCHEDULE INFO
            plenum_values = get_values('hood_no2')
            for i in range(len(plenum_values)):
                plenum_info = {
                    'HOOD_NO': extract_value(plenum_values, i),
                    'PLENUMDEPTH': extract_value(get_values('plenum_depth'), 0),
                    'PLENUMLENGTH': extract_value(get_values('plenum_length'), 0),
                    'PLENUMLENGTHTOTAL': extract_value(get_values('hood_length'), i) + extract_value(get_values('cab_width'), i),
                    'MUA_COLLAR_QTY': extract_value(get_values('mua_collars_qty'), i),
                    'MUA_COLLAR_SIZE': f"{extract_value(get_values('mua_collar_length'), i)} X {extract_value(get_values('mua_collar_width'), i)}",
                    'COLLAR_SP': extract_value(get_values('mua_collars_sp'), i),
                    'COLLAR_CFM': extract_value(get_values('mua_collars_cfm'), i),
                    'MUA_AREA': extract_value(get_values('mua_area'), i),
                    'MUA_VELOCITY': extract_value(get_values('mua_vel'), i),
                    'PLENUM_WGT': extract_value(get_values('plenum_weight'), i)
                }
                json_data['InputParams']['PLENUM_SCHEDULE_INFO'].append(plenum_info)
            
            # FAN SCHEDULE INFO
            fan_values = get_values('hood_no3')
            for i in range(len(fan_values)):
                fan_info = {
                    'HOOD_NO': extract_value(fan_values, i),
                    'MFG': extract_value(get_values('fan_model'), i),
                    'LABEL': extract_value(get_values('label'), i),
                    'MODEL': extract_value(get_values('fan_mfg'), i),
                    'CFM': extract_value(get_values('fan_cfm'), i),
                    'SP': extract_value(get_values('fan_sp'), i),
                    'HP': extract_value(get_values('fan_hp'), i),
                    'VOLTAGE': extract_value(get_values('fan_voltage'), i),
                    'PHASE': extract_value(get_values('fan_phase'), i),
                    'RPM': extract_value(get_values('fan_rpm'), i),
                    'AMPS': extract_value(get_values('fan_amps'), i),
                    'WGT': extract_value(get_values('fan_weight'), i),
                }
                json_data['InputParams']['FAN_SCHEDULE_INFO'].append(fan_info)
            
            json_data['InputParams']['FrontElevation'] = {
                'tower_height': extract_value(get_values('tower_height'), 0) or 150,
                'tower_width': extract_value(get_values('tower_width'), 0) or 10,
                'number_of_hoods': number_of_hoods or 2
            }
            
            json_data['InputParams']['SectionView'] = {
                'tower_height': extract_value(get_values('tower_height'), 0) or 150,
                'tower_width': extract_value(get_values('tower_width'), 0) or 10,
                'hood_height': extract_value(get_values('hood_height'), 0) or 30,
                'hood_width': extract_value(get_values('hood_width'), 0) or 54,
                'plenum_depth': extract_value(get_values('plenum_depth'), 0) or 16,
                'plenum_length': extract_value(get_values('plenum_length'), 0) or 8
            }

            dxf_file_path = create_drawing_file(json_data, number_of_hoods)
            response = FileResponse(open(dxf_file_path, 'rb'), content_type='application/dxf')
            response['Content-Disposition'] = f'attachment; filename="{os.path.basename(dxf_file_path)}"'
            return response
        else:
            print(form.errors)
    else:
        form = CreateDrawingForm()
    return render(request, 'createdrawing/create_drawing.html', {'create_drawing_form': form})